@@ -51,7 +51,7 @@ SSMtrend <- function(degree = 1, Q, type, index, a1, P1, P1inf, n = 1, state_nam
       stop("P1inf must be a (m x m) diagonal matrix where m is the number of states. ")
     P1inf <- matrix(P1inf, m, m)
   }
-  diag(P1inf)[diag(P1) > 0 || is.na(diag(P1))] <- 0
+  diag(P1inf)[diag(P1) > 0 | is.na(diag(P1))] <- 0
   if (missing(Q)) {
     k <- 0
     Qm <- R <- NULL
